==> zio-aws-personalizeruntime_2.13-5.17.177.1-sources.jar: zio/aws/personalizeruntime/model/package.scala <==
package zio.aws.personalizeruntime
import zio.prelude.Subtype
import zio.aws.personalizeruntime.model.primitives.{
  FilterAttributeName,
  AttributeName,
  ItemID,
  FilterAttributeValue,
  AttributeValue
}
import zio.aws.personalizeruntime.model.primitives.ItemID.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.personalizeruntime.model.primitives.Arn.Type
    object AttributeName extends Subtype[String]
    type AttributeName =
      zio.aws.personalizeruntime.model.primitives.AttributeName.Type
    object AttributeValue extends Subtype[String]
    type AttributeValue =
      zio.aws.personalizeruntime.model.primitives.AttributeValue.Type
    object FilterAttributeName extends Subtype[String]
    type FilterAttributeName =
      zio.aws.personalizeruntime.model.primitives.FilterAttributeName.Type
    object FilterAttributeValue extends Subtype[String]
    type FilterAttributeValue =
      zio.aws.personalizeruntime.model.primitives.FilterAttributeValue.Type
    object ItemID extends Subtype[String]
    type ItemID = zio.aws.personalizeruntime.model.primitives.ItemID.Type
    object NumResults extends Subtype[Int]
    type NumResults =
      zio.aws.personalizeruntime.model.primitives.NumResults.Type
    object RecommendationID extends Subtype[String]
    type RecommendationID =
      zio.aws.personalizeruntime.model.primitives.RecommendationID.Type
    object Score extends Subtype[Double]
    type Score = zio.aws.personalizeruntime.model.primitives.Score.Type
    object UserID extends Subtype[String]
    type UserID = zio.aws.personalizeruntime.model.primitives.UserID.Type
  }
  type Context = Map[AttributeName, AttributeValue]
  type FilterValues = Map[FilterAttributeName, FilterAttributeValue]
  type InputList = List[ItemID]
  type ItemList = List[zio.aws.personalizeruntime.model.PredictedItem]
}

==> zio-aws-personalizeruntime_2.13-6.20.78.2-sources.jar: zio/aws/personalizeruntime/model/package.scala <==
package zio.aws.personalizeruntime
import zio.prelude.Subtype
import zio.aws.personalizeruntime.model.primitives.{
  FilterAttributeName,
  AttributeName,
  ItemID,
  FilterAttributeValue,
  AttributeValue
}
import zio.aws.personalizeruntime.model.primitives.ItemID.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.personalizeruntime.model.primitives.Arn.Type
    object AttributeName extends Subtype[String]
    type AttributeName =
      zio.aws.personalizeruntime.model.primitives.AttributeName.Type
    object AttributeValue extends Subtype[String]
    type AttributeValue =
      zio.aws.personalizeruntime.model.primitives.AttributeValue.Type
    object FilterAttributeName extends Subtype[String]
    type FilterAttributeName =
      zio.aws.personalizeruntime.model.primitives.FilterAttributeName.Type
    object FilterAttributeValue extends Subtype[String]
    type FilterAttributeValue =
      zio.aws.personalizeruntime.model.primitives.FilterAttributeValue.Type
    object ItemID extends Subtype[String]
    type ItemID = zio.aws.personalizeruntime.model.primitives.ItemID.Type
    object Name extends Subtype[String]
    type Name = zio.aws.personalizeruntime.model.primitives.Name.Type
    object NumResults extends Subtype[Int]
    type NumResults =
      zio.aws.personalizeruntime.model.primitives.NumResults.Type
    object PercentPromotedItems extends Subtype[Int]
    type PercentPromotedItems =
      zio.aws.personalizeruntime.model.primitives.PercentPromotedItems.Type
    object RecommendationID extends Subtype[String]
    type RecommendationID =
      zio.aws.personalizeruntime.model.primitives.RecommendationID.Type
    object Score extends Subtype[Double]
    type Score = zio.aws.personalizeruntime.model.primitives.Score.Type
    object UserID extends Subtype[String]
    type UserID = zio.aws.personalizeruntime.model.primitives.UserID.Type
  }
  type Context = Map[AttributeName, AttributeValue]
  type FilterValues = Map[FilterAttributeName, FilterAttributeValue]
  type InputList = List[ItemID]
  type ItemList = List[zio.aws.personalizeruntime.model.PredictedItem]
  type PromotionList = List[zio.aws.personalizeruntime.model.Promotion]
}
